#[derive(generate_auto_impl_impl)]Expand description
Generates a default blanket impl for a generic trait that gets passed into
generate_auto_impl_impl, with the same type parameters and type bounds as its trait.
Arguments
input- A string slice of the trait source.